cmd

package
v0.0.0-...-17fa81c Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 12, 2026 License: MIT Imports: 23 Imported by: 0

Documentation

Overview

Copyright © 2024 NAME HERE <EMAIL ADDRESS>

Copyright © 2024 NAME HERE <EMAIL ADDRESS>

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Execute

func Execute()

Execute adds all child commands to the root command and sets flags appropriately. This is called by main.main(). It only needs to happen once to the rootCmd.

func WithLogger

func WithLogger(logger *zap.Logger) func(http.Handler) http.Handler

func WithOtelTracerContext

func WithOtelTracerContext(tracer trace.Tracer) func(http.Handler) http.Handler

Types

This section is empty.

Jump to